@@ -76,7 +76,7 @@ enum {
 };
 
 G_DEFINE_TYPE (GpmBrightnessKbd, gpm_brightness_kbd, G_TYPE_OBJECT)
-static guint	     signals [LAST_SIGNAL] = { 0, };
+static guint	     signals [LAST_SIGNAL] = { 0 };
 
 /**
  * gpm_brightness_kbd_get_hw:
@@ -224,7 +224,7 @@ gpm_brightness_kbd_get_step (GpmBrightnessKbd *brightness)
 {
 	int step;
 
-	g_return_val_if_fail (brightness != NULL, FALSE);
+	g_return_val_if_fail (brightness != NULL, 0);
 	g_return_val_if_fail (GPM_IS_BRIGHTNESS_KBD (brightness), 0);
 
 	if (brightness->priv->levels < 20) {
@@ -570,7 +570,7 @@ adjust_kbd_brightness_according_to_ambient_light (GpmBrightnessKbd *brightness,
 		return FALSE;
 	}
 
-	gpm_light_sensor_get (brightness->priv->sensor, &ambient_light);
+	gpm_light_sensor_get_absolute (brightness->priv->sensor, &ambient_light);
 
 	/* this is also used if user reenables the keyboard backlight */
 	if (startup) {
