@@ -39,14 +39,12 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <gtk/gtkstatusicon.h>
-#include <libgnomeui/gnome-help.h>
 
 #include "gpm-conf.h"
 #include "gpm-control.h"
 #include "gpm-common.h"
 #include "gpm-debug.h"
 #include "gpm-notify.h"
-#include "gpm-control.h"
 #include "gpm-cell-array.h"
 #include "gpm-cell.h"
 #include "gpm-cell-unit.h"
@@ -70,6 +68,7 @@ struct GpmTrayIconPrivate
 	gboolean		 is_visible;
 	gboolean		 show_suspend;
 	gboolean		 show_hibernate;
+	gboolean		 show_context_menu;
 };
 
 enum {
@@ -83,7 +82,7 @@ enum {
 	PROP_MODE
 };
 
-static guint	 signals [LAST_SIGNAL] = { 0, };
+static guint	 signals [LAST_SIGNAL] = { 0 };
 
 G_DEFINE_TYPE (GpmTrayIcon, gpm_tray_icon, G_TYPE_OBJECT)
 
@@ -126,6 +125,14 @@ gpm_tray_icon_enable_hibernate (GpmTrayIcon *icon,
 	icon->priv->show_hibernate = enabled;
 }
 
+static void
+gpm_tray_icon_enable_context_menu (GpmTrayIcon *icon,
+				   gboolean     enabled)
+{
+	g_return_if_fail (GPM_IS_TRAY_ICON (icon));
+	icon->priv->show_context_menu = enabled;
+}
+
 /**
  * gpm_tray_icon_show:
  * @icon: This TrayIcon class instance
@@ -276,13 +283,7 @@ gpm_tray_icon_show_preferences_cb (GtkMenuItem *item, gpointer data)
 static void
 gpm_tray_icon_show_help_cb (GtkMenuItem *item, gpointer data)
 {
-	GError *error = NULL;
-
-	gnome_help_display ("gnome-power-manager.xml", NULL, &error);
-	if (error != NULL) {
-		gpm_warning (error->message);
-		g_error_free (error);
-	}
+	gpm_help_display (NULL);
 }
 
 /**
@@ -437,6 +438,9 @@ gpm_tray_icon_popup_menu_cb (GtkStatusIcon *status_icon,
 
 	gpm_debug ("icon right clicked");
 
+	if (!icon->priv->show_context_menu)
+		return;
+
 	/* Preferences */
 	item = gtk_image_menu_item_new_with_mnemonic (_("_Preferences"));
 	image = gtk_image_new_from_icon_name (GTK_STOCK_PREFERENCES, GTK_ICON_SIZE_MENU);
@@ -560,6 +564,7 @@ gpm_tray_icon_activate_cb (GtkStatusIcon *status_icon,
 	/* add all device types to the drop down menu */
 	dev_cnt += gpm_tray_icon_add_device (icon, menu, icon->priv->collection->primary);
 	dev_cnt += gpm_tray_icon_add_device (icon, menu, icon->priv->collection->ups);
+	dev_cnt += gpm_tray_icon_add_device (icon, menu, icon->priv->collection->phone);
 	dev_cnt += gpm_tray_icon_add_device (icon, menu, icon->priv->collection->mouse);
 	dev_cnt += gpm_tray_icon_add_device (icon, menu, icon->priv->collection->keyboard);
 	dev_cnt += gpm_tray_icon_add_device (icon, menu, icon->priv->collection->pda);
@@ -636,6 +641,9 @@ conf_key_changed_cb (GpmConf     *conf,
 		gpm_tray_icon_enable_suspend (icon, allowed_in_menu && enabled);
 		gpm_control_allowed_hibernate (icon->priv->control, &enabled, NULL);
 		gpm_tray_icon_enable_hibernate (icon, allowed_in_menu && enabled);
+	} else if (strcmp (key, GPM_CONF_UI_SHOW_CONTEXT_MENU) == 0) {
+		gpm_conf_get_bool (icon->priv->conf, GPM_CONF_UI_SHOW_CONTEXT_MENU, &allowed_in_menu);
+		gpm_tray_icon_enable_context_menu (icon, allowed_in_menu);
 	}
 }
 
@@ -684,6 +692,9 @@ gpm_tray_icon_init (GpmTrayIcon *icon)
 	gpm_control_allowed_hibernate (icon->priv->control, &enabled, NULL);
 	gpm_tray_icon_enable_hibernate (icon, enabled && allowed_in_menu);
 
+	gpm_conf_get_bool (icon->priv->conf, GPM_CONF_UI_SHOW_CONTEXT_MENU, &allowed_in_menu);
+	gpm_tray_icon_enable_context_menu (icon, allowed_in_menu);
+
 	gpm_tray_icon_show (GPM_TRAY_ICON (icon), FALSE);
 }
 
